<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class LocaisAtendimentoFactory {

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    // INTEGRAÇÃO COM SM
    public function getContratosConfigurarLocais() {

        $sql = "SELECT FCT_RELACESTRUTURACONT.*, FCT_CONTRATO.NRCONTRATOFCT 
                    FROM FCT_RELACESTRUTURACONT
                    JOIN FCT_CONTRATO
                    ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACESTRUTURACONT.NRSEQCONTRATO";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);

    }

    public function getLocaisSM($parametros) {

        $sql = "SELECT DISTINCT FCT_RELACESTRUTURACONT.NRRELACESTRUTCONT, FCT_RELACESTRUTURACONT.NRESTRUTURAM, FCT_RELACESTRUTURACONT.NRSEQCONTRATO, ESTRUTURAM.NMESTRUTURAM
                    FROM FCT_RELACESTRUTURACONT
                    JOIN ESTRUTURAM
                    ON ESTRUTURAM.NRESTRUTURAM = FCT_RELACESTRUTURACONT.NRESTRUTURAM
                    WHERE FCT_RELACESTRUTURACONT.NRSEQCONTRATO IN ({$parametros})";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getClienteContrato($parametros) {

        $sql = "SELECT CLIENTE.CDCLIENTE 
                    FROM CLIENTE
                    JOIN FCT_CONTRATO
                      ON FCT_CONTRATO.NRPARCNEGOCIO = CLIENTE.NRPARCNEGOCIO
                    WHERE FCT_CONTRATO.NRSEQCONTRATO = $parametros";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        $retorno = $std->fetchAll();
        return $retorno[0]['CDCLIENTE'];
    }

    public function verificarExistenciaLocais($parametro) {
        
        $sql = "SELECT COUNT(*) NRESTRUTURAM
                    FROM FCM_LOCALCLI
                    WHERE NRESTRUTURAM = $parametro
                    AND IDATIVO = 'S'";

        $std = $this->connection->prepare($sql);
        $std->execute();
        $st = $std->fetchAll();
        return $st[0]['NRESTRUTURAM'];
    }
    // -------------------
    public function getClientes() {
        
        $sql = "SELECT CDCLIENTE, NMFANTCLIE
                FROM CLIENTE
                where IDCLIEATIV = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getLocais() {

        $sql = "SELECT LC.NRLOCALCLIENTE, LC.NMLOCALCLIENTE, TP.IDTIPOLOCALCLI, LC.NRTIPOLOCALCLI, LC.NRESTRUTURAM
                    FROM FCM_LOCALCLI LC
                    JOIN FCM_TIPOLOCALCLI TP
                      ON TP.NRTIPOLOCALCLI = LC.NRTIPOLOCALCLI
                    WHERE TP.IDTIPOLOCALCLI <> 3";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);

    }

    public function getTiposDeLocais($parametros) {
        
        $sql = "SELECT NMTIPOLOCALCLI, NRTIPOLOCALCLI, IDTIPOLOCALCLI
                    FROM FCM_TIPOLOCALCLI
                   WHERE IDTIPOLOCALCLI IN (DECODE(:IDTIPOLOCALCLI, NULL, 1, DECODE(:IDTIPOLOCALCLI, 1, 2, DECODE (:IDTIPOLOCALCLI, 2, 3, NULL))))
       
                UNION ALL 
       
                SELECT NMTIPOLOCALCLI, NRTIPOLOCALCLI, IDTIPOLOCALCLI
                    FROM FCM_TIPOLOCALCLI
                   WHERE IDTIPOLOCALCLI IN (DECODE(:IDTIPOLOCALCLI, NULL, 1, DECODE(:IDTIPOLOCALCLI, 1, 2, DECODE (:IDTIPOLOCALCLI, 2, 2, NULL))))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getChecklistPadrao() {

        $sql = "SELECT NMCHECKLIST, NRCHECKLIST
                  FROM FCM_CHECKLIST
                  WHERE IDATIVO = 'S'";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getSetorLocalAtendimento() {

        $sql = "SELECT NRSETOR, NMSETOR
                    FROM FCM_SETOR
                    WHERE IDATIVO = 'S'";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getClientesQueAgrupamLocais() {

        $sql = "SELECT DISTINCT C.CDCLIENTE, C.NMFANTCLIE, LC.DSCORIDLOCAL
                     FROM  CLIENTE C 
                     JOIN FCM_LOCALCLI LC
                     ON C.CDCLIENTE = LC.CDCLIENTE
                     WHERE LC.IDATIVO = 'S'";
         
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getLocaisAgrupados($parametro) {
        $sql = "SELECT LOC.NMLOCALCLIENTE, LOC.NRLOCALCLIENTE, LOC.NRLOCALCLIENTEPAI, LOC.DSCODIGOLOCALCLI, LOC.CDCLIENTE,
                        TLOC.NMTIPOLOCALCLI, TLOC.IDTIPOLOCALCLI,LOC.NRTIPOLOCALCLI, LOC.NRCHECKLISTPADR, LOC.NRSETOR, LOC.DSCORIDLOCAL, LOC.NMABREVLOCALCLI, LOC.IDATIVO, LOC.NRESTRUTURAM
                        FROM FCM_LOCALCLI LOC
                        JOIN FCM_TIPOLOCALCLI TLOC
                        ON TLOC.NRTIPOLOCALCLI =  LOC.NRTIPOLOCALCLI
                    WHERE LOC.CDCLIENTE = :CDCLIENTE
                    AND LOC.IDATIVO = 'S'
                    ORDER BY TLOC.IDTIPOLOCALCLI ASC";

       // adicionar esta linha abaixo do where caso seja necessário aplicar o fetchOnDemand = true no frontend
      //  -- AND ((LOC.NRLOCALCLIENTEPAI = :NRLOCALCLIENTEPAI)  OR ((:NRLOCALCLIENTEPAI IS NULL) AND (LOC.NRLOCALCLIENTEPAI IS NULL)))

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getCorCliente($parametros) {


        $sql = "SELECT DISTINCT DSCORIDLOCAL
                    FROM FCM_LOCALCLI
                    WHERE CDCLIENTE = :CDCLIENTE";
        
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
        return $std->fetchAll();

    }

    public function atualizarLocal($parametros) {

        $sql = "UPDATE FCM_LOCALCLI
                    SET NMLOCALCLIENTE = :NMLOCALCLIENTE,
                        CDCLIENTE      = :CDCLIENTE,
                        NRTIPOLOCALCLI = :NRTIPOLOCALCLI,
                        NRLOCALCLIENTEPAI = :NRLOCALCLIENTEPAI,
                        NRCHECKLISTPADR = :NRCHECKLISTPADR,
                        DTULTATU = SYSDATE,
                        DSCODIGOLOCALCLI = :DSCODIGOLOCALCLI,
                        NMABREVLOCALCLI = :NMABREVLOCALCLI,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                WHERE NRLOCALCLIENTE = :NRLOCALCLIENTE";
                
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function inserirNovoLocal($parametros) {

        $sql = "INSERT INTO FCM_LOCALCLI (NRLOCALCLIENTE, NMLOCALCLIENTE, CDCLIENTE ,NRTIPOLOCALCLI, NRLOCALCLIENTEPAI, NRCHECKLISTPADR, DSQRCODE, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, DSCODIGOLOCALCLI, DSCORIDLOCAL, NMABREVLOCALCLI, NRESTRUTURAM)
                    VALUES ( :NRLOCALCLIENTE, 
                            :NMLOCALCLIENTE, 
                            :CDCLIENTE,
                            :NRTIPOLOCALCLI,
                            :NRLOCALCLIENTEPAI,
                            :NRCHECKLISTPADR,
                            :DSQRCODE,
                            'S', 
                            :NRORG,
                            SYSDATE, 
                            :CDOPERINCLUSAO, 
                            :NRORGINCLUSAO, 
                            :DSCODIGOLOCALCLI,
                            :DSCORIDLOCAL,
                            :NMABREVLOCALCLI,
                            :NRESTRUTURAM)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);

    }

    public function inserirRelacLocalChk($paramsChk) {
        $sql = "INSERT INTO FCM_RELACLOCALCHK (NRRELACLOCALCHK, NRLOCALCLIENTE, NRCHECKLIST, DTINCLUSAO, DTULTATU)
                    VALUES(:NRRELACLOCALCHK, :NRLOCALCLIENTE, :NRCHECKLIST, SYSDATE, SYSDATE)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($paramsChk);
    }

    public function alterarCorCliente($parametros) {
        
        $sql = "UPDATE FCM_LOCALCLI
                    SET DSCORIDLOCAL = :DSCORIDLOCAL,
                        DTULTATU = SYSDATE, 
                        NRORGULTATU = :NRORGULTATU,
                        CDOPERULTATU = :CDOPERULTATU
                    WHERE CDCLIENTE = :CDCLIENTE";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function verificarExistenciaFilhos($parametros) {

        $sql = "SELECT COUNT(*) FILHOS
                    FROM FCM_LOCALCLI
                    WHERE NRLOCALCLIENTEPAI = ".$parametros."
                    AND IDATIVO = 'S'";

        
        $std = $this->connection->prepare($sql);
        $std->execute();
        $st = $std->fetchAll();
        return $st[0]['FILHOS'];
    }

    public function inativarLocais($parametros) {
        
        $sql = "UPDATE FCM_LOCALCLI
                    SET IDATIVO = 'N',
                        CDOPERULTATU =:CDOPERULTATU,
                        DTULTATU = SYSDATE,
                        NRORGULTATU = :NRORGULTATU
                    WHERE NRLOCALCLIENTE = :NRLOCALCLIENTE";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }


    // --- Funções da TAB DE TIPO DE LOCAL
    public function getTipoDeLocal() {

        $sql = "SELECT DISTINCT T1.NMTIPOLOCALCLI, T1.NRTIPOLOCALCLI, T1.IDTIPOLOCALCLI, T2.NRTIPOLOCALCLI as VALIDA
                FROM FCM_TIPOLOCALCLI T1
                LEFT JOIN FCM_LOCALCLI T2 ON T1.NRTIPOLOCALCLI = T2.NRTIPOLOCALCLI
                ORDER BY T1.IDTIPOLOCALCLI ASC";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function validaTipoLocalUsado() {

        $sql = "SELECT NMTIPOLOCALCLI, NRTIPOLOCALCLI, IDTIPOLOCALCLI
                    FROM FCM_TIPOLOCALCLI 
                 ORDER BY IDTIPOLOCALCLI ASC";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function excluirTipoLocal($parametros) {

        $sql = "DELETE FROM FCM_TIPOLOCALCLI WHERE NRTIPOLOCALCLI = :NRTIPOLOCALCLI ";    
        $this->connection->executeStatement($sql, $parametros);

    }

    public function atualizarTipoLocal($parametros) {
        
        $sql = "UPDATE FCM_TIPOLOCALCLI
                    SET NMTIPOLOCALCLI = :NMTIPOLOCALCLI,
                        IDTIPOLOCALCLI = :IDTIPOLOCALCLI,
                        NRORGULTATU    = :NRORGULTATU,
                        CDOPERULTATU   = :CDOPERULTATU,
                        DTULTATU = SYSDATE
                    WHERE NRTIPOLOCALCLI = :NRTIPOLOCALCLI";
        
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function inserirTipoLocal($parametros) {

         $sql = "INSERT INTO FCM_TIPOLOCALCLI (NRTIPOLOCALCLI, NMTIPOLOCALCLI, IDTIPOLOCALCLI, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO, DTINCLUSAO)
                    VALUES(:NRTIPOLOCALCLI, 
                           :NMTIPOLOCALCLI, 
                           :IDTIPOLOCALCLI,
                           :NRORG,
                           :NRORGINCLUSAO,
                           :CDOPERINCLUSAO, 
                           :IDATIVO,
                           SYSDATE)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }
}