<?php
namespace FM\Service;

use FM\Factory\LocaisAtendimentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\FindService;

class LocaisAtendimentoService {

    protected $LocaisAtendimentoFactory;
    protected $FindService;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, LocaisAtendimentoFactory $LocaisAtendimentoFactory, FindService $FindService, Environment $Environment, NewCode $newCode) {
        $this->connection                = $entityManager->getConnection();
        $this->LocaisAtendimentoFactory  = $LocaisAtendimentoFactory;
        $this->FindService               = $FindService;
        $this->Environment               = $Environment;
        $this->newCode                   = $newCode;
    }
    // INTEGRAÇÃO COM SM
    public function getContratosConfigurarLocais() {
        return $this->LocaisAtendimentoFactory->getContratosConfigurarLocais();
    }

    Public function getLocaisSM($parametros) {
        
        $arrayFormatado = $this->FindService->formatarArray($parametros['NRSEQCONTRATO']);
        return $this->LocaisAtendimentoFactory->getLocaisSM($arrayFormatado);
    }

    public function salvarLocalSm($parametros) {
        $retorno = array();

        foreach($parametros as $arrayLocal) {

            $localExistente = $this->LocaisAtendimentoFactory->verificarExistenciaLocais($arrayLocal['NRESTRUTURAM']);

            if ($localExistente == 0) {
                $cdCliente = $this->LocaisAtendimentoFactory->getClienteContrato($arrayLocal['NRSEQCONTRATO']);
            
                $params = array (
                    "NMLOCALCLIENTE"    => $arrayLocal['NMESTRUTURAM'],
                    "CDCLIENTE"         => $cdCliente,
                    "NRTIPOLOCALCLI"    => $arrayLocal['NRTIPOLOCALCLI'],
                    "NRESTRUTURAM"      => $arrayLocal['NRESTRUTURAM'],
                    "NRLOCALCLIENTEPAI" => null,
                    "NRCHECKLISTPADR"   => null,
                    "DSQRCODE"          => null,
                    "DSCODIGOLOCALCLI"  => $arrayLocal['DSCODIGOLOCALCLI'],
                    "DSCORIDLOCAL"      => $arrayLocal['DSCORIDLOCAL'],
                    "NMABREVLOCALCLI"   => $arrayLocal['NMABREVLOCALCLI']
                );

                $this->inserirNovoLocal($params);

            } else {
                array_push($retorno, $arrayLocal['NMESTRUTURAM']);
            }
            
        }
        return $retorno;
    }

    // ------------
    public function getClientes() {
        return $this->LocaisAtendimentoFactory->getClientes();
    }

    public function getLocais() {
        return $this->LocaisAtendimentoFactory->getLocais();
    }

    public function getTiposDeLocais($parametros) {
        
        $param = array(
            "IDTIPOLOCALCLI" => ($parametros['IDTIPOLOCALCLI'] === "0") ? null : $parametros['IDTIPOLOCALCLI']
        );

        return $this->LocaisAtendimentoFactory->getTiposDeLocais($param);
    }

    public function getChecklistPadrao() {
        return $this->LocaisAtendimentoFactory->getChecklistPadrao();
    }

    public function getSetorLocalAtendimento() {
        return $this->LocaisAtendimentoFactory->getSetorLocalAtendimento();
    }

    public function inserirNovoLocal($parametros) {
        $this->connection->beginTransaction();

        try {
            $nrorg      = $this->Environment->getNrorg();
            $nrLocalCliente = $this->newCode->getCodeByTableName('FCM_LOCALCLI', $nrorg, 1, 10, true);
            $cdOperador = $this->Environment->getCdOperador();
            
            $p = array (
                "CDCLIENTE"         => $parametros['CDCLIENTE']
            );

            $cor = $this->LocaisAtendimentoFactory->getCorCliente($p);

            $params = array (
                "NRLOCALCLIENTE"    => $nrLocalCliente,
                "NMLOCALCLIENTE"    => $parametros['NMLOCALCLIENTE'],
                "CDCLIENTE"         => $parametros['CDCLIENTE'],
                "NRTIPOLOCALCLI"    => $parametros['NRTIPOLOCALCLI'],
                "NRLOCALCLIENTEPAI" => $parametros['NRLOCALCLIENTEPAI'],
                "NRCHECKLISTPADR"   => $parametros['NRCHECKLISTPADR'],
                "DSQRCODE"          => null,
                "NRORG"             => $nrorg,
                "CDOPERINCLUSAO"    => $cdOperador,
                "NRORGINCLUSAO"     => $nrorg,
                "DSCODIGOLOCALCLI"  => $parametros['DSCODIGOLOCALCLI'],
                "DSCORIDLOCAL"      => (!empty($cor)) ? $cor[0]['DSCORIDLOCAL'] : $parametros['DSCORIDLOCAL'],
                "NMABREVLOCALCLI"   => $parametros['NMABREVLOCALCLI'],
                "NRESTRUTURAM"      => $parametros['NRESTRUTURAM'],
            );

            $this->LocaisAtendimentoFactory->inserirNovoLocal($params);

            if ($parametros['NRCHECKLISTPADR'] !== null) {
                $nrRelacLocalChk = $this->newCode->getCodeByTableName('FCM_RELACLOCALCHK', $nrorg, 1, 10, true);

                $paramsChk = array(
                    "NRRELACLOCALCHK" => $nrRelacLocalChk,
                    "NRLOCALCLIENTE"  => $nrLocalCliente,
                    "NRCHECKLIST"     => $parametros['NRCHECKLISTPADR']
                );
                
                $this->LocaisAtendimentoFactory->inserirRelacLocalChk($paramsChk);
            }

            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getClientesQueAgrupamLocais() {
        return $this->LocaisAtendimentoFactory->getClientesQueAgrupamLocais();
    }

    public function getLocaisAgrupados($parametro) {
        // descomentar essa linha caso seja necessário aplicar o fetchOnDemand como true no frontend
        $param = array(
            "CDCLIENTE" => $parametro['CDCLIENTE'],
            // "NRLOCALCLIENTEPAI" => ($parametro['NRLOCALCLIENTEPAI'] === 'NULL') ? null : $parametro['NRLOCALCLIENTEPAI']
        );

        return $this->LocaisAtendimentoFactory->getLocaisAgrupados($param);
    }

    public function alterarCorCliente($parametros) {
        $this->connection->beginTransaction();

        try {
            $nrorg      = $this->Environment->getNrorg();
            $cdOperador = $this->Environment->getCdOperador();
        
            $param = array(
                "DSCORIDLOCAL" => $parametros['DSCORIDLOCAL'],
                "CDCLIENTE"    => $parametros['CDCLIENTE'],
                "NRORGULTATU"  => $nrorg,
                "CDOPERULTATU" => $cdOperador,

            );
    
            $this->LocaisAtendimentoFactory->alterarCorCliente($param);

            $this->connection->commit();
        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function atualizarLocal($parametros) {
        $this->connection->beginTransaction();

        try {
            $nrorg      = $this->Environment->getNrorg();
            $cdOperador = $this->Environment->getCdOperador();

            $p = array (
                "CDCLIENTE"         => $parametros['CDCLIENTE']
            );

            $cor = $this->LocaisAtendimentoFactory->getCorCliente($p);

            $params = array (
                "NRLOCALCLIENTE"    => $parametros['NRLOCALCLIENTE'],
                "NMLOCALCLIENTE"    => $parametros['NMLOCALCLIENTE'],
                "CDCLIENTE"         => $parametros['CDCLIENTE'],
                "NRTIPOLOCALCLI"    => $parametros['NRTIPOLOCALCLI'],
                "NRLOCALCLIENTEPAI" => $parametros['NRLOCALCLIENTEPAI'],
                "NRCHECKLISTPADR"   => $parametros['NRCHECKLISTPADR'],
                "NMABREVLOCALCLI"   => $parametros['NMABREVLOCALCLI'],
                "DSCODIGOLOCALCLI"  => $parametros['DSCODIGOLOCALCLI'],
                "NRORGULTATU"       => $nrorg,
                "CDOPERULTATU"      => $cdOperador,
            );
            
            $this->LocaisAtendimentoFactory->atualizarLocal($params);

            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function inativarLocais($parametros) {
        $this->connection->beginTransaction();
        
        try {
            $cont = 0;
            $contLocaisFilhos = 0;
            $filtrados = '';
            $nrorg      = $this->Environment->getNrorg();
            $cdOperador = $this->Environment->getCdOperador();

            
            while ($cont <= 2) {
                $indice = (3 - $cont);

                switch ($indice) {
                    case 1:
                        $filtrados = $parametros['TIPO1'];
                        break;
                    case 2:
                        $filtrados = $parametros['TIPO2'];
                        break;
                    case 3:
                        $filtrados = $parametros['TIPO3'];
                        break;
                }

                forEach($filtrados as $filtrado) {
                    $filhos = $this->LocaisAtendimentoFactory->verificarExistenciaFilhos($filtrado);

                    if ($filhos == 0) {

                        $params = array (
                            "NRLOCALCLIENTE" => $filtrado,
                            "NRORGULTATU"    => $nrorg,
                            "CDOPERULTATU"   => $cdOperador,
                        );
                        
                        $this->LocaisAtendimentoFactory->inativarLocais($params);

                    } else {
                        $contLocaisFilhos++;
                    }
                }
                $cont++;
            }

            echo '<pre>';
            print_r();
            exit;
            $this->connection->commit();
            return $mensagem = ($contLocaisFilhos == 0) ? 'Ok' : 'err';

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    // --- Funções da TAB DE TIPO DE LOCAL
    public function getTipoDeLocal() {
        return $this->LocaisAtendimentoFactory->getTipoDeLocal();
    }

    public function excluirTipoLocal($params) {

        $this->connection->beginTransaction();

        try {
            foreach ($params['NRS'] as $chave => $linha) {
                $dataParam = array("NRTIPOLOCALCLI" => $linha);
                $this->LocaisAtendimentoFactory->excluirTipoLocal($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function atualizarTipoLocal($params){

        $this->connection->beginTransaction();
        
        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();
            
            foreach ($params["DRG"] as $row ){

                if($row["NRTIPOLOCALCLI"] != 0 ){
                    $parametros = array (
                        "NRTIPOLOCALCLI" => $row["NRTIPOLOCALCLI"],
                        "NMTIPOLOCALCLI" => $row['NMTIPOLOCALCLI'],
                        "IDTIPOLOCALCLI" => $row['IDTIPOLOCALCLI'],
                        "NRORGULTATU"    => $nrorg,
                        "CDOPERULTATU"   => $operador
                    );
                    
                    $this->LocaisAtendimentoFactory->atualizarTipoLocal($parametros);
                } else {                    
                    $nrtipolocalcli = $this->newCode->getCodeByTableName('FCM_TIPOLOCALCLI', $nrorg, 1, 10, true);
                    $parametros = array (
                        "NRTIPOLOCALCLI" => $nrtipolocalcli,
                        "NMTIPOLOCALCLI" => $row['NMTIPOLOCALCLI'],
                        "IDTIPOLOCALCLI" => $row['IDTIPOLOCALCLI'],
                        "NRORG"          => $nrorg,
                        "NRORGINCLUSAO"  => $nrorg,
                        "CDOPERINCLUSAO" => $operador,
                        "IDATIVO"        => "S"
                    );

                    $this->LocaisAtendimentoFactory->inserirTipoLocal($parametros);
                }                    
            }
            $this->connection->commit();
        }catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

}