import {
    Http, IDictionary,
} from '@zeedhi/core';
import {
    ApexChart,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class Fm00000001DashboardSupervisorController {
    // responsavel por pegar os dados do chard Tarefas Realizadas e plotar as informações
    public async getDadosChartTarefasRealizadas({ component }: { component: ApexChart }) {
        Http.get('/getDadosChartTarefas').then((response: IDictionary) => {
            const { dados } = response.data.dataset;
            if (dados.length > 0) {
                dados.forEach((data: IDictionary) => {
                    component.options.labels.push(data.NMATIVIDADE);
                    (component.series as any[]).push(data.QUANTIDADE);
                    component.options.colors.push(data.DSCORIDATIVIDADE);
                });
            } else {
                component.options.labels.push('Não há dados disponíveis');
                (component.series as any[]).push(1);
                component.options.colors.push('#57737a');
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public async getDadosChartNaoConformidade({ component }: { component: ApexChart }) {
        Http.get('/getDadosChartNaoConformidades').then((response: IDictionary) => {
            const { dados } = response.data.dataset;
            if (dados.length) {
                dados.forEach((dadosGraf: IDictionary) => {
                    (component.series as any[]).push({
                        name: dadosGraf.NMATIVIDADE,
                        data: [dadosGraf.QUANTIDADE],
                    });
                    component.options.colors.push(dadosGraf.DSCORIDATIVIDADE);
                });
            } else {
                (component.series as any[]).push({
                    name: 'Nenhum dado disponível',
                    data: [100],
                });
                component.options.colors.push('#57737a');
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public async dailyProgressChart({ component }: { component: ApexChart }) {
        Http.get('/getDadosChartProgressoMensal').then((response: IDictionary) => {
            const { dados } = response.data.dataset;
            if (dados.length) {
                dados.forEach((dadosGraf: IDictionary) => {
                    (component.series as any[]).push({
                        name: dadosGraf.NMATIVIDADE,
                        data: [`${dadosGraf.PORCENTAGEM}%`],
                    });
                    component.options.colors.push(dadosGraf.DSCORIDATIVIDADE);
                });
            } else {
                (component.series as any[]).push({
                    name: 'Nenhum dado disponível',
                    data: [100],
                });
                component.options.colors.push('#57737a');
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }
}
